## ----style, eval=TRUE, echo=FALSE, results='asis'---------------------------------------
BiocStyle::latex()

## ----eval = FALSE-----------------------------------------------------------------------
#  library(affycoretools)
#  eset <- justRMA(cdfname = "hsfocushsentrezgcdf")

## ----echo=FALSE, results="hide"---------------------------------------------------------
library(affycoretools)
load("exprSet2.Rdata")

## ---------------------------------------------------------------------------------------
library(limma)
design <- model.matrix(~ 0 + factor(rep(1:4, each = 3)))
colnames(design) <- LETTERS[1:4]
contrast <- makeContrasts(A-B, C-D, levels = design)
fit <- lmFit(eset, design)
fit2 <- contrasts.fit(fit, contrast)
fit2 <- eBayes(fit2)

## ----eval=FALSE-------------------------------------------------------------------------
#  limma2biomaRt(eset, fit2, design, contrast,
#                species = "hsapiens", pfilt = 0.05,
#                interactive = FALSE)

## ----echo = FALSE, results="hide"-------------------------------------------------------
dt <- decideTests(fit2, method = "nestedF")
rslt <- vennCounts2(dt)

## ----eval=FALSE-------------------------------------------------------------------------
#  dt <- decideTests(fit2, method = "nestedF")
#  rslt <- vennCounts2(dt)
#  vennDiagram(rslt)

## ----venn, fig.cap = "Venn diagram", echo = FALSE---------------------------------------
vennDiagram(rslt)

## ----eval=FALSE-------------------------------------------------------------------------
#  vennSelectBM(eset, design, dt,
#               contrast, fit2, species = "hsapiens")

## ---------------------------------------------------------------------------------------
library(biomaRt)
annBM()
mart <- useMart("ensembl",
                "hsapiens_gene_ensembl")
annBM(mart, species="hsapiens")
mart <- useMart("ensembl",
                "celegans_gene_ensembl")
annBM(mart, species="celegans")

## ----sessioninfo, echo=FALSE, results="asis"--------------------------------------------
toLatex(sessionInfo())

